@@ -14,10 +14,12 @@ class NewRelicAlerts(object):
 
   def __init__(self, context, clients):
     self.config = EFConfig.PLUGINS['newrelic']
-    self.conditions = self.config.get('alert_conditions', {})
+    self.ec2_conditions = self.config.get('ec2_alert_conditions', {})
+    self.ecs_conditions = self.config.get('ecs_alert_conditions', {})
     self.local_alert_nrql_conditions = self.config.get('alert_nrql_conditions', {})
     self.admin_token = self.config.get('admin_token', "")
     self.all_notification_channels = self.config.get('env_notification_map', {})
+    self.opsgenie_api_key = self.config["opsgenie_api_key"]
     self.context, self.clients = context, clients
 
   @classmethod
@@ -46,11 +48,14 @@ class NewRelicAlerts(object):
       logger.info("create alert policy {}".format(policy.name))
     return policy
 
-  def populate_alert_policy_values(self, policy):
+  def populate_alert_policy_values(self, policy, service_type):
     policy.id = next(alert['id'] for alert in self.newrelic.all_alert_policies if alert['name'] == policy.name)
     policy.notification_channels = self.all_notification_channels[self.context.env]
     policy.remote_conditions = self.newrelic.get_policy_alert_conditions(policy.id)
-    policy.config_conditions = deepcopy(self.conditions)
+    if service_type in ['aws_ec2', 'http_service']:
+      policy.config_conditions = deepcopy(self.ec2_conditions)
+    elif service_type in ['aws_ecs', 'aws_ecs_http']:
+      policy.config_conditions = deepcopy(self.ecs_conditions)
     policy.remote_alert_nrql_conditions = self.newrelic.get_policy_alert_nrql_conditions(policy.id)
     policy.local_alert_nrql_conditions = deepcopy(self.local_alert_nrql_conditions)
 
@@ -121,7 +126,7 @@ class NewRelicAlerts(object):
       self.newrelic.create_alert_policy(policy.name)
       logger.info("create alert policy {}".format(policy.name))
 
-    self.populate_alert_policy_values(policy)
+    self.populate_alert_policy_values(policy, 'aws_fixture')
     self.add_alert_policy_to_notification_channels(policy)
 
     conditions = {}
@@ -143,6 +148,23 @@ class NewRelicAlerts(object):
         self.newrelic.add_policy_channels(policy.id, [channel['id']])
         logger.info("add channel_ids {} to policy {}".format(policy.name, channel['id']))
 
+  def add_policy_to_opsgenie_channel(self, policy, team_name):
+    team_channel = self.newrelic.get_notification_channel_by_name(team_name)
+    if not team_channel or team_channel['type'] != 'opsgenie':
+      team_channel = self.newrelic.create_opsgenie_alert_channel(
+        name=team_name,
+        api_key=self.opsgenie_api_key,
+        teams=[team_name]
+      )
+
+    if policy.id in team_channel['links']['policy_ids']:
+      return
+
+    chan_id = team_channel['id']
+
+    self.newrelic.add_policy_channels(policy.id, [chan_id])
+    logger.info("add OpsGenie channel id:%s for team %s to policy %s", chan_id, team_name, policy.name)
+
   def replace_symbols_in_condition(self, policy):
     # Replace symbols in config alert conditions
     for key, value in policy.config_conditions.items():
@@ -180,10 +202,14 @@ class NewRelicAlerts(object):
           self.newrelic.put_policy_alert_nrql_condition(remote_alert_nrql_condition["id"], local_alert_nrql_condition)
 
   def update_application_services_policies(self):
-    for service in self.context.service_registry.iter_services(service_group="application_services"):
-      service_name = service[0]
-      service_environments = service[1]['environments']
-      service_alert_overrides = service[1]['alerts'] if "alerts" in service[1] else {}
+    for service_name, service_config in self.context.service_registry.iter_services(service_group="application_services"):
+      service_environments = service_config['environments']
+      service_alert_overrides = service_config.get('alerts', {})
+      opsgenie_team = service_config.get("team_opsgenie", "")
+      service_type = service_config['type']
+
+      if service_type not in ['aws_ec2', 'aws_ecs', 'aws_ecs_http', 'http_service']:
+        continue
 
       if self.context.env in service_environments:
         policy = AlertPolicy(env=self.context.env, service=service_name)
@@ -194,8 +220,9 @@ class NewRelicAlerts(object):
           logger.info("create alert policy {}".format(policy.name))
 
         # Update AlertPolicy object
-        self.populate_alert_policy_values(policy)
+        self.populate_alert_policy_values(policy, service_type)
         self.add_alert_policy_to_notification_channels(policy)
+        self.add_policy_to_opsgenie_channel(policy, opsgenie_team)
         self.replace_symbols_in_condition(policy)
 
         # Infra alert conditions
